var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.register = void 0;
const shared = require("@volar/shared");
const path = require("typesafe-path");
const vscode = require("vscode-languageserver");
const protocol_1 = require("../protocol");
const language_core_1 = require("@volar/language-core");
function register(connection, projects) {
    connection.onRequest(protocol_1.GetMatchTsConfigRequest.type, (params) => __awaiter(this, void 0, void 0, function* () {
        var _a;
        const project = (yield projects.getProject(params.uri));
        if (project) {
            return {
                fileName: project.tsconfig,
                raw: (_a = project.project) === null || _a === void 0 ? void 0 : _a.getParsedCommandLine().raw,
            };
        }
    }));
    connection.onRequest(protocol_1.GetVirtualFileNamesRequest.type, (document) => __awaiter(this, void 0, void 0, function* () {
        var _b, _c;
        const project = yield projects.getProject(document.uri);
        const fileNames = [];
        if (project) {
            const sourceFile = (_c = (_b = project.project) === null || _b === void 0 ? void 0 : _b.getLanguageService().context.core.mapper.get(shared.getPathOfUri(document.uri))) === null || _c === void 0 ? void 0 : _c[0];
            if (sourceFile) {
                (0, language_core_1.forEachEmbeddeds)(sourceFile.embeddeds, e => {
                    if (e.text && e.kind === 1) {
                        fileNames.push(e.fileName);
                    }
                });
            }
        }
        return fileNames;
    }));
    connection.onRequest(protocol_1.GetVirtualFileRequest.type, (params) => __awaiter(this, void 0, void 0, function* () {
        var _d, _e;
        const project = yield projects.getProject(params.sourceFileUri);
        if (project) {
            const embeddedFile = (_e = (_d = project.project) === null || _d === void 0 ? void 0 : _d.getLanguageService().context.core.mapper.fromEmbeddedFileName(params.virtualFileName)) === null || _e === void 0 ? void 0 : _e.embedded;
            if (embeddedFile) {
                return {
                    content: embeddedFile.text,
                    mappings: embeddedFile.mappings,
                };
            }
        }
    }));
    connection.onNotification(protocol_1.ReloadProjectNotification.type, (params) => __awaiter(this, void 0, void 0, function* () {
        projects.reloadProject();
    }));
    connection.onNotification(protocol_1.WriteVirtualFilesNotification.type, (params) => __awaiter(this, void 0, void 0, function* () {
        var _f;
        const fs = yield Promise.resolve().then(() => require('fs'));
        const project = yield projects.getProject(params.uri);
        if (project) {
            const ls = (_f = (yield project.project)) === null || _f === void 0 ? void 0 : _f.getLanguageServiceDontCreate();
            if (ls) {
                const sourceFiles = new Set(ls.context.host.getScriptFileNames());
                for (const virtualFile of ls.context.core.typescriptLanguageServiceHost.getScriptFileNames()) {
                    if (virtualFile.startsWith(ls.context.host.getCurrentDirectory()) && !sourceFiles.has(virtualFile)) {
                        const snapshot = ls.context.core.typescriptLanguageServiceHost.getScriptSnapshot(virtualFile);
                        if (snapshot) {
                            fs.writeFile(virtualFile, snapshot.getText(0, snapshot.getLength()), () => { });
                        }
                    }
                }
            }
        }
    }));
    connection.onNotification(protocol_1.VerifyAllScriptsNotification.type, (params) => __awaiter(this, void 0, void 0, function* () {
        var _g;
        let errors = 0;
        let warnings = 0;
        const progress = yield connection.window.createWorkDoneProgress();
        progress.begin('Verify', 0, '', true);
        const project = yield projects.getProject(params.uri);
        if (project) {
            const ls = (_g = (yield project.project)) === null || _g === void 0 ? void 0 : _g.getLanguageServiceDontCreate();
            if (ls) {
                const allVueDocuments = ls.context.documents.getAll();
                let i = 0;
                for (const vueFile of allVueDocuments) {
                    progress.report(i++ / allVueDocuments.length * 100, path.relative(ls.context.host.getCurrentDirectory(), shared.getPathOfUri(vueFile.uri)));
                    if (progress.token.isCancellationRequested) {
                        continue;
                    }
                    let _result = yield ls.doValidation(vueFile.uri, progress.token);
                    connection.sendDiagnostics({ uri: vueFile.uri, diagnostics: _result });
                    errors += _result.filter(error => error.severity === vscode.DiagnosticSeverity.Error).length;
                    warnings += _result.filter(error => error.severity === vscode.DiagnosticSeverity.Warning).length;
                }
            }
        }
        progress.done();
        connection.window.showInformationMessage(`Verification complete. Found ${errors} errors and ${warnings} warnings.`);
    }));
}
exports.register = register;
//# sourceMappingURL=customFeatures.js.map