Object.defineProperty(exports, "__esModule", { value: true });
exports.createCancellactionTokenHost = void 0;
const vscode = require("vscode-languageserver");
function createCancellactionTokenHost(_cancellationPipeName) {
    if (_cancellationPipeName === undefined) {
        return {
            createCancellactionToken(original) {
                return original;
            },
            getMtime() {
                return -1;
            }
        };
    }
    const cancellationPipeName = _cancellationPipeName;
    const fs = require('fs');
    return {
        createCancellactionToken,
        getMtime,
    };
    function createCancellactionToken(original) {
        const mtime = getMtime();
        const token = {
            get isCancellationRequested() {
                if (original.isCancellationRequested) {
                    return true;
                }
                return getMtime() !== mtime;
            },
            onCancellationRequested: vscode.Event.None,
        };
        return token;
    }
    function getMtime() {
        try {
            return fs.statSync(cancellationPipeName).mtime.valueOf();
        }
        catch (_a) {
            return -1;
        }
    }
}
exports.createCancellactionTokenHost = createCancellactionTokenHost;
//# sourceMappingURL=cancellationPipe.js.map