import * as embeddedLS from '@volar/language-service';
import type * as ts from 'typescript/lib/tsserverlibrary';
import * as vscode from 'vscode-languageserver';
import { URI } from 'vscode-uri';
import { FileSystemHost, LanguageServerPlugin, RuntimeEnvironment } from '../types';
import { createSnapshots } from './snapshots';
import { ConfigurationHost } from '@volar/language-service';
import * as path from 'typesafe-path';
import { CancellactionTokenHost } from './cancellationPipe';
export interface Project extends ReturnType<typeof createProject> {
}
export declare function createProject(runtimeEnv: RuntimeEnvironment, plugins: ReturnType<LanguageServerPlugin>[], fsHost: FileSystemHost, ts: typeof import('typescript/lib/tsserverlibrary'), rootUri: URI, tsConfig: path.PosixPath | ts.CompilerOptions, tsLocalized: ts.MapLike<string> | undefined, documents: ReturnType<typeof createSnapshots>, configHost: ConfigurationHost | undefined, documentRegistry: ts.DocumentRegistry | undefined, cancelTokenHost: CancellactionTokenHost): Promise<{
    getLanguageService: () => {
        doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
        findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
        findFileReferences: (uri: string) => embeddedLS.NullableResult<vscode.Location[]>;
        findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
        findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
        findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
        prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
        doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
        getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
        getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: embeddedLS.SemanticToken[]) => void) | undefined) => Promise<embeddedLS.SemanticToken[] | undefined> | undefined;
        doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
        doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
            isIncomplete: boolean;
            items: vscode.CompletionItem[];
        }>;
        doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
        doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
        doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
        getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
        doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
        doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
        findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
        findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
        findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
        doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
            lastChange: {
                range: vscode.Range;
                rangeOffset: number;
                rangeLength: number;
                text: string;
            };
        }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
        doExecuteCommand: (command: string, args: embeddedLS.ExecutePluginCommandArgs, executeCommandContext: embeddedLS.ExecuteCommandContext) => Promise<void>;
        getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
        callHierarchy: {
            doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
            getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
            getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
        };
        dispose: () => void;
        context: embeddedLS.LanguageServiceRuntimeContext;
    };
    getLanguageServiceDontCreate: () => {
        doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
        findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
        findFileReferences: (uri: string) => embeddedLS.NullableResult<vscode.Location[]>;
        findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
        findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
        findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
        prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
        doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
        getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
        getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: embeddedLS.SemanticToken[]) => void) | undefined) => Promise<embeddedLS.SemanticToken[] | undefined> | undefined;
        doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
        doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
            isIncomplete: boolean;
            items: vscode.CompletionItem[];
        }>;
        doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
        doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
        doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
        getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
        doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
        doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
        findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
        findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
        findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
        doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
            lastChange: {
                range: vscode.Range;
                rangeOffset: number;
                rangeLength: number;
                text: string;
            };
        }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
        doExecuteCommand: (command: string, args: embeddedLS.ExecutePluginCommandArgs, executeCommandContext: embeddedLS.ExecuteCommandContext) => Promise<void>;
        getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
        callHierarchy: {
            doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
            getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
            getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
        };
        dispose: () => void;
        context: embeddedLS.LanguageServiceRuntimeContext;
    } | undefined;
    getParsedCommandLine: () => ts.ParsedCommandLine;
    dispose: () => void;
}>;
