import { TextDocument } from 'vscode-languageserver-textdocument';
import * as vscode from 'vscode-languageserver';
import * as shared from '@volar/shared';
import type * as ts from 'typescript/lib/tsserverlibrary';
interface IncrementalScriptSnapshotChange {
    applyed: boolean;
    changeRange: ts.TextChangeRange | undefined;
    version: number;
    contentChange: {
        range: vscode.Range;
        text: string;
    } | undefined;
    snapshot: WeakRef<ts.IScriptSnapshot> | undefined;
}
declare class IncrementalScriptSnapshot {
    private document;
    uri: string;
    changes: IncrementalScriptSnapshotChange[];
    constructor(uri: string, languageId: string, version: number, text: string);
    get version(): number;
    update(params: vscode.DidChangeTextDocumentParams): void;
    getSnapshot(): ts.IScriptSnapshot;
    getDocument(): TextDocument;
    clearUnReferenceVersions(): void;
    applyVersionToRootDocument(version: number, removeBeforeVersions: boolean): void;
}
export declare function combineContinuousChangeRanges(...changeRanges: ts.TextChangeRange[]): ts.TextChangeRange;
export declare function createSnapshots(connection: vscode.Connection): {
    data: {
        clear: () => void;
        values: () => IterableIterator<IncrementalScriptSnapshot>;
        uriDelete: (_uri: string) => boolean;
        uriGet: (_uri: string) => IncrementalScriptSnapshot | undefined;
        uriHas: (_uri: string) => boolean;
        uriSet: (_uri: string, item: IncrementalScriptSnapshot) => void;
        pathDelete: (rootUri: shared._2.URI, path: string) => boolean;
        pathGet: (rootUri: shared._2.URI, path: string) => IncrementalScriptSnapshot | undefined;
        pathHas: (rootUri: shared._2.URI, path: string) => IncrementalScriptSnapshot | undefined;
        pathSet: (rootUri: shared._2.URI, path: string, item: IncrementalScriptSnapshot) => void;
    };
    onDidOpen: (cb: (params: vscode.DidOpenTextDocumentParams) => void) => () => boolean;
    onDidChangeContent: (cb: (params: vscode.DidChangeTextDocumentParams) => void) => () => boolean;
    onDidClose: (cb: (params: vscode.DidCloseTextDocumentParams) => void) => () => boolean;
};
export {};
