import * as shared from '@volar/shared';
import { ConfigurationHost } from '@volar/language-service';
import type * as ts from 'typescript/lib/tsserverlibrary';
import * as vscode from 'vscode-languageserver';
import { URI } from 'vscode-uri';
import { FileSystemHost, LanguageServerPlugin, RuntimeEnvironment, LanguageServerInitializationOptions } from '../types';
import { createSnapshots } from './snapshots';
import { CancellactionTokenHost } from './cancellationPipe';
export interface Workspaces extends ReturnType<typeof createWorkspaces> {
}
export declare function createWorkspaces(runtimeEnv: RuntimeEnvironment, plugins: ReturnType<LanguageServerPlugin>[], fsHost: FileSystemHost, configurationHost: ConfigurationHost | undefined, ts: typeof import('typescript/lib/tsserverlibrary'), tsLocalized: ts.MapLike<string> | undefined, client: vscode.ClientCapabilities, options: LanguageServerInitializationOptions, documents: ReturnType<typeof createSnapshots>, connection: vscode.Connection, cancelTokenHost: CancellactionTokenHost): {
    workspaces: Map<string, Promise<{
        projects: {
            clear: () => void;
            values: () => IterableIterator<import("./project").Project>;
            uriDelete: (_uri: string) => boolean;
            uriGet: (_uri: string) => import("./project").Project | undefined;
            uriHas: (_uri: string) => boolean;
            uriSet: (_uri: string, item: import("./project").Project) => void;
            pathDelete: (rootUri: shared._2.URI, path: string) => boolean;
            pathGet: (rootUri: shared._2.URI, path: string) => import("./project").Project | undefined;
            pathHas: (rootUri: shared._2.URI, path: string) => import("./project").Project | undefined;
            pathSet: (rootUri: shared._2.URI, path: string, item: import("./project").Project) => void;
        };
        getProjectAndTsConfig: (uri: string) => Promise<{
            tsconfig: string;
            project: {
                getLanguageService: () => {
                    doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
                    findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
                    findFileReferences: (uri: string) => import("@volar/language-service").NullableResult<vscode.Location[]>;
                    findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                    findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                    findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                    prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
                    doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
                    getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
                    getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: import("@volar/language-service").SemanticToken[]) => void) | undefined) => Promise<import("@volar/language-service").SemanticToken[] | undefined> | undefined;
                    doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
                    doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
                        isIncomplete: boolean;
                        items: vscode.CompletionItem[];
                    }>;
                    doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
                    doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
                    doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
                    getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
                    doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
                    doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
                    findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
                    findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
                    findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
                    doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
                        lastChange: {
                            range: vscode.Range;
                            rangeOffset: number;
                            rangeLength: number;
                            text: string;
                        };
                    }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
                    doExecuteCommand: (command: string, args: import("@volar/language-service").ExecutePluginCommandArgs, executeCommandContext: import("@volar/language-service").ExecuteCommandContext) => Promise<void>;
                    getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
                    callHierarchy: {
                        doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
                        getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
                        getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
                    };
                    dispose: () => void;
                    context: import("@volar/language-service").LanguageServiceRuntimeContext;
                };
                getLanguageServiceDontCreate: () => {
                    doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
                    findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
                    findFileReferences: (uri: string) => import("@volar/language-service").NullableResult<vscode.Location[]>;
                    findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                    findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                    findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                    prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
                    doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
                    getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
                    getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: import("@volar/language-service").SemanticToken[]) => void) | undefined) => Promise<import("@volar/language-service").SemanticToken[] | undefined> | undefined;
                    doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
                    doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
                        isIncomplete: boolean;
                        items: vscode.CompletionItem[];
                    }>;
                    doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
                    doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
                    doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
                    getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
                    doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
                    doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
                    findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
                    findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
                    findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
                    doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
                        lastChange: {
                            range: vscode.Range;
                            rangeOffset: number;
                            rangeLength: number;
                            text: string;
                        };
                    }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
                    doExecuteCommand: (command: string, args: import("@volar/language-service").ExecutePluginCommandArgs, executeCommandContext: import("@volar/language-service").ExecuteCommandContext) => Promise<void>;
                    getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
                    callHierarchy: {
                        doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
                        getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
                        getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
                    };
                    dispose: () => void;
                    context: import("@volar/language-service").LanguageServiceRuntimeContext;
                } | undefined;
                getParsedCommandLine: () => ts.ParsedCommandLine;
                dispose: () => void;
            };
        } | undefined>;
        getInferredProject: () => import("./project").Project;
        reload: () => void;
        dispose(): void;
    }>>;
    getProject: (uri: string) => Promise<{
        tsconfig: string;
        project: {
            getLanguageService: () => {
                doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
                findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
                findFileReferences: (uri: string) => import("@volar/language-service").NullableResult<vscode.Location[]>;
                findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
                doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: import("@volar/language-service").SemanticToken[]) => void) | undefined) => Promise<import("@volar/language-service").SemanticToken[] | undefined> | undefined;
                doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
                doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
                    isIncomplete: boolean;
                    items: vscode.CompletionItem[];
                }>;
                doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
                doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
                doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
                getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
                doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
                doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
                findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
                findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
                findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
                doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
                    lastChange: {
                        range: vscode.Range;
                        rangeOffset: number;
                        rangeLength: number;
                        text: string;
                    };
                }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
                doExecuteCommand: (command: string, args: import("@volar/language-service").ExecutePluginCommandArgs, executeCommandContext: import("@volar/language-service").ExecuteCommandContext) => Promise<void>;
                getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
                callHierarchy: {
                    doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
                    getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
                    getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
                };
                dispose: () => void;
                context: import("@volar/language-service").LanguageServiceRuntimeContext;
            };
            getLanguageServiceDontCreate: () => {
                doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
                findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
                findFileReferences: (uri: string) => import("@volar/language-service").NullableResult<vscode.Location[]>;
                findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
                doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: import("@volar/language-service").SemanticToken[]) => void) | undefined) => Promise<import("@volar/language-service").SemanticToken[] | undefined> | undefined;
                doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
                doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
                    isIncomplete: boolean;
                    items: vscode.CompletionItem[];
                }>;
                doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
                doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
                doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
                getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
                doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
                doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
                findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
                findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
                findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
                doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
                    lastChange: {
                        range: vscode.Range;
                        rangeOffset: number;
                        rangeLength: number;
                        text: string;
                    };
                }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
                doExecuteCommand: (command: string, args: import("@volar/language-service").ExecutePluginCommandArgs, executeCommandContext: import("@volar/language-service").ExecuteCommandContext) => Promise<void>;
                getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
                callHierarchy: {
                    doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
                    getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
                    getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
                };
                dispose: () => void;
                context: import("@volar/language-service").LanguageServiceRuntimeContext;
            } | undefined;
            getParsedCommandLine: () => ts.ParsedCommandLine;
            dispose: () => void;
        };
    } | {
        tsconfig: undefined;
        project: {
            getLanguageService: () => {
                doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
                findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
                findFileReferences: (uri: string) => import("@volar/language-service").NullableResult<vscode.Location[]>;
                findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
                doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: import("@volar/language-service").SemanticToken[]) => void) | undefined) => Promise<import("@volar/language-service").SemanticToken[] | undefined> | undefined;
                doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
                doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
                    isIncomplete: boolean;
                    items: vscode.CompletionItem[];
                }>;
                doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
                doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
                doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
                getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
                doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
                doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
                findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
                findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
                findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
                doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
                    lastChange: {
                        range: vscode.Range;
                        rangeOffset: number;
                        rangeLength: number;
                        text: string;
                    };
                }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
                doExecuteCommand: (command: string, args: import("@volar/language-service").ExecutePluginCommandArgs, executeCommandContext: import("@volar/language-service").ExecuteCommandContext) => Promise<void>;
                getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
                callHierarchy: {
                    doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
                    getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
                    getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
                };
                dispose: () => void;
                context: import("@volar/language-service").LanguageServiceRuntimeContext;
            };
            getLanguageServiceDontCreate: () => {
                doValidation: (uri: string, token?: vscode.CancellationToken | undefined, response?: ((result: vscode.Diagnostic[]) => void) | undefined) => Promise<vscode.Diagnostic[]>;
                findReferences: (uri: string, position: vscode.Position) => Promise<vscode.Location[] | undefined>;
                findFileReferences: (uri: string) => import("@volar/language-service").NullableResult<vscode.Location[]>;
                findDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findTypeDefinition: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                findImplementations: (uri: string, position: vscode.Position) => Promise<vscode.LocationLink[] | undefined>;
                prepareRename: (uri: string, position: vscode.Position) => Promise<NonNullable<vscode.Range | vscode.ResponseError<void> | null | undefined> | undefined>;
                doRename: (uri: string, position: vscode.Position, newName: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getEditsForFileRename: (oldUri: string, newUri: string) => Promise<vscode.WorkspaceEdit | undefined>;
                getSemanticTokens: (uri: string, range: vscode.Range | undefined, cancleToken: vscode.CancellationToken, reportProgress?: ((tokens: import("@volar/language-service").SemanticToken[]) => void) | undefined) => Promise<import("@volar/language-service").SemanticToken[] | undefined> | undefined;
                doHover: (uri: string, position: vscode.Position) => Promise<vscode.Hover | undefined>;
                doComplete: (uri: string, position: vscode.Position, completionContext?: vscode.CompletionContext | undefined) => Promise<{
                    isIncomplete: boolean;
                    items: vscode.CompletionItem[];
                }>;
                doCodeActions: (uri: string, range: vscode.Range, codeActionContext: vscode.CodeActionContext) => Promise<vscode.CodeAction[] | undefined>;
                doCodeActionResolve: (item: vscode.CodeAction) => Promise<vscode.CodeAction>;
                doCompletionResolve: (item: vscode.CompletionItem) => Promise<vscode.CompletionItem>;
                getSignatureHelp: (uri: string, position: vscode.Position, signatureHelpContext?: vscode.SignatureHelpContext | undefined) => Promise<vscode.SignatureHelp | undefined>;
                doCodeLens: (uri: string) => Promise<vscode.CodeLens[]>;
                doCodeLensResolve: (item: vscode.CodeLens) => Promise<vscode.CodeLens>;
                findDocumentHighlights: (uri: string, position: vscode.Position) => Promise<vscode.DocumentHighlight[] | undefined>;
                findDocumentLinks: (uri: string) => Promise<vscode.DocumentLink[]>;
                findWorkspaceSymbols: (query: string) => Promise<vscode.SymbolInformation[]>;
                doAutoInsert: (uri: string, position: vscode.Position, autoInsertContext: {
                    lastChange: {
                        range: vscode.Range;
                        rangeOffset: number;
                        rangeLength: number;
                        text: string;
                    };
                }) => Promise<NonNullable<string | vscode.TextEdit | null | undefined> | undefined>;
                doExecuteCommand: (command: string, args: import("@volar/language-service").ExecutePluginCommandArgs, executeCommandContext: import("@volar/language-service").ExecuteCommandContext) => Promise<void>;
                getInlayHints: (uri: string, range: vscode.Range) => Promise<vscode.InlayHint[] | undefined>;
                callHierarchy: {
                    doPrepare(uri: string, position: vscode.Position): Promise<vscode.CallHierarchyItem[] | undefined>;
                    getIncomingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyIncomingCall[]>;
                    getOutgoingCalls(item: vscode.CallHierarchyItem): Promise<vscode.CallHierarchyOutgoingCall[]>;
                };
                dispose: () => void;
                context: import("@volar/language-service").LanguageServiceRuntimeContext;
            } | undefined;
            getParsedCommandLine: () => ts.ParsedCommandLine;
            dispose: () => void;
        } | undefined;
    } | undefined>;
    reloadProject: () => Promise<void>;
    add: (rootUri: URI) => void;
    remove: (rootUri: URI) => void;
};
